==> queueshare-0.0.55.tgz: package/src/qcBumpPlaylist.js <==
import ArrayLastValue from './ArrayLastValue.js'
import assert from './assert.js'
import QcQueueGroups from './QcQueueGroups.js'
import QcPlaylistPositions from './QcPlaylistPositions.js'
import QcPlaylistMap from './QcPlaylistMap.js'
import qcQueueMap from './qcQueueMap.js'
import qcSkipForward from './qcSkipForward.js'
import QcsMediaExists from './QcsMediaExists.js'
import qcsCollabMap from './qcsCollabMap.js'
import QcQueuePositions from './QcQueuePositions.js'
import QcQueueIsPlaying from './QcQueueIsPlaying.js'
import CollabPosition from './CollabPosition.js'

const qcBumpPlaylist = (playlist) => {
	if (QcsMediaExists(playlist)) {
		const positions = QcQueuePositions()
		const firstIndexOrNegativeOne = positions.findIndex((position) => {
			return qcQueueMap.get(position).playlist === playlist
		})
		if (firstIndexOrNegativeOne === -1) {
			const playlistPositions = QcPlaylistPositions(playlist)
			if (playlistPositions.length !== 0) {
				if (positions.length === 0) {
					QcQueueIsPlaying.set(false)
				}
				const playlistMap = QcPlaylistMap(playlist)
				let afterPositionOrNull = positions.length === 0 ? null : positions[positions.length - 1]
				for (const playlistPosition of playlistPositions) {
					const position = CollabPosition(afterPositionOrNull, null)
					qcsCollabMap.set(
						'media-' + playlistMap.get(playlistPosition) + '-playlists-' + playlist + '-queueInfo',
						JSON.stringify({position: position}),
					)
					afterPositionOrNull = position
				}
			}
		} else {
			const firstIndex = firstIndexOrNegativeOne
			if (firstIndex === 0) {
				if (!QcQueueIsPlaying()) {
					QcQueueIsPlaying.set(true)
				}
			} else if (firstIndex === 1 && QcQueueIsPlaying()) {
				qcSkipForward()
			} else {
				const groups = QcQueueGroups()
				const firstGroupIndex = groups.findIndex((group) => {
					return qcQueueMap.get(group[0]).playlist === playlist
				})
				assert(firstGroupIndex !== -1)
				assert(firstGroupIndex !== 0)
				let afterPositionOrNull
				let beforePosition
				if (firstGroupIndex === 1 && QcQueueIsPlaying()) {
					assert(firstIndex > 1)
					afterPositionOrNull = positions[0]
					beforePosition = positions[1]
				} else {
					afterPositionOrNull = firstGroupIndex === 1 ? null : ArrayLastValue(groups[firstGroupIndex - 2])
					beforePosition = groups[firstGroupIndex - 1][0]
				}
				for (const value of positions.map((position) => {
					return qcQueueMap.get(position)
				})) {
					if (value.playlist === playlist) {
						const newPosition = CollabPosition(afterPositionOrNull, beforePosition)
						qcsCollabMap.set(
							'media-' + value.track + '-playlists-' + playlist + '-queueInfo',
							JSON.stringify({position: newPosition}),
						)
						afterPositionOrNull = newPosition
					}
				}
			}
		}
	}
}

export default qcBumpPlaylist

==> queueshare-0.0.57.tgz: package/src/qcBumpPlaylist.js <==
import QcBumpNumber from './QcBumpNumber.js'
import QcBumpGroups from './QcBumpGroups.js'
import assert from './assert.js'
import QcPlaylistPositions from './QcPlaylistPositions.js'
import QcPlaylistMap from './QcPlaylistMap.js'
import qcQueueMap from './qcQueueMap.js'
import qcSkipForward from './qcSkipForward.js'
import QcsMediaExists from './QcsMediaExists.js'
import qcsCollabMap from './qcsCollabMap.js'
import QcQueuePositions from './QcQueuePositions.js'
import QcQueueIsPlaying from './QcQueueIsPlaying.js'
import CollabPosition from './CollabPosition.js'

const qcBumpPlaylist = (playlist) => {
	if (QcsMediaExists(playlist)) {
		const positions = QcQueuePositions()
		const firstIndexOrNegativeOne = positions.findIndex((position) => {
			return qcQueueMap.get(position).playlist === playlist
		})
		if (firstIndexOrNegativeOne === -1) {
			const playlistPositions = QcPlaylistPositions(playlist)
			if (playlistPositions.length !== 0) {
				if (positions.length === 0) {
					QcQueueIsPlaying.set(false)
				}
				const playlistMap = QcPlaylistMap(playlist)
				let afterPositionOrNull = positions.length === 0 ? null : positions[positions.length - 1]
				let bumpNumberOrNull = null
				for (const playlistPosition of playlistPositions) {
					const position = CollabPosition(afterPositionOrNull, null)
					if (bumpNumberOrNull === null) {
						bumpNumberOrNull = QcBumpNumber(position, QcBumpGroups())
					}
					qcsCollabMap.set(
						'media-' + playlistMap.get(playlistPosition) + '-playlists-' + playlist + '-queueInfo',
						JSON.stringify({position: position, bumpNumber: bumpNumberOrNull}),
					)
					afterPositionOrNull = position
				}
			}
		}
		else {
			const firstIndex = firstIndexOrNegativeOne
			if (firstIndex === 0) {
				if (!QcQueueIsPlaying()) {
					QcQueueIsPlaying.set(true)
				}
			}
			else if (firstIndex === 1 && QcQueueIsPlaying()) {
				qcSkipForward()
			}
			else {
				const groups = QcBumpGroups()
				const firstGroupIndex = groups.findLastIndex((group) => {
					return group.positions.some((groupPosition) => {
						return positions[firstIndex] > groupPosition
					})
				})
				assert(firstGroupIndex !== -1) // if firstGroupIndex === -1, firstIndex === 0 and that case has already been handled
				let afterPositionOrNull = firstGroupIndex === 0 ? null : groups[firstGroupIndex - 1].positions.at(-1)
				const beforePosition = groups[firstGroupIndex].positions[0]
				let bumpNumberOrNull = null
				for (const value of positions.map((position) => {
					return qcQueueMap.get(position)
				})) {
					if (value.playlist === playlist) {
						const newPosition = CollabPosition(afterPositionOrNull, beforePosition)
						if (bumpNumberOrNull === null) {
							bumpNumberOrNull = QcBumpNumber(newPosition, QcBumpGroups({withoutPositions: new Set(positions.filter((position) => {
								return qcQueueMap.get(position).playlist === playlist
							}))}))
						}
						qcsCollabMap.set(
							'media-' + value.track + '-playlists-' + playlist + '-queueInfo',
							JSON.stringify({position: newPosition, bumpNumber: bumpNumberOrNull}),
						)
						afterPositionOrNull = newPosition
					}
				}
			}
		}
	}
}

export default qcBumpPlaylist
